=======
Eingang
=======

Eingang is `Flask Security <http://pythonhosted.org/Flask-Security>`_
with `Bootstrap <http://getbootstrap.com>`_.

Create a starter Eingang website:
::

   virtualenv -p python3 venv
   venv/bin/pip install eingang
   venv/bin/eingang_create.sh
   make project
   venv/bin/python app.py
